@@ -1,4 +1,5 @@
 import datetime
+import shutil
 from collections.abc import Iterable
 from pathlib import Path
 from pprint import pprint
@@ -6,9 +7,14 @@ from unittest import TestCase
 
 from bx_py_utils.path import assert_is_file
 
+import manageprojects
 from manageprojects.utilities.pyproject_toml import toml_load
 
 
+PROJECT_PATH = Path(manageprojects.__file__).parent.parent
+GIT_BIN_PARENT = Path(shutil.which('git')).parent
+
+
 class BaseTestCase(TestCase):
     maxDiff = None
 
